==> qtjambi-webenginewidgets-5.15.17-sources.jar: io/qt/webengine/widgets/QWebEngineScript.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Encapsulates a JavaScript program</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html">QWebEngineScript</a></code></p>
 */
public class QWebEngineScript extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::InjectionPoint</a></code></p>
     */
    public enum InjectionPoint implements QtEnumerator {
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::<wbr>Deferred</a></code></p>
         */
        Deferred(0),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::<wbr>DocumentReady</a></code></p>
         */
        DocumentReady(1),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::<wbr>DocumentCreation</a></code></p>
         */
        DocumentCreation(2);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private InjectionPoint(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull InjectionPoint resolve(int value) {
            switch (value) {
            case 0: return Deferred;
            case 1: return DocumentReady;
            case 2: return DocumentCreation;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::ScriptWorldId</a></code></p>
     */
    public enum ScriptWorldId implements QtEnumerator {
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::<wbr>MainWorld</a></code></p>
         */
        MainWorld(0),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::<wbr>ApplicationWorld</a></code></p>
         */
        ApplicationWorld(1),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::<wbr>UserWorld</a></code></p>
         */
        UserWorld(2);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private ScriptWorldId(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull ScriptWorldId resolve(int value) {
            switch (value) {
            case 0: return MainWorld;
            case 1: return ApplicationWorld;
            case 2: return UserWorld;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>QWebEngineScript()</code></p>
     */
    public QWebEngineScript(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineScript instance);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>QWebEngineScript(QWebEngineScript)</code></p>
     */
    public QWebEngineScript(io.qt.webengine.widgets.@NonNull QWebEngineScript other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineScript instance, io.qt.webengine.widgets.QWebEngineScript other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>injectionPoint()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineScript.@NonNull InjectionPoint injectionPoint(){
        return io.qt.webengine.widgets.QWebEngineScript.InjectionPoint.resolve(injectionPoint_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int injectionPoint_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>isNull()const</code></p>
     */
    @QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>name()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>operator=(QWebEngineScript)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineScript other){
        assign_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineScript(long __this__nativeId, long other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>operator==(QWebEngineScript)const</code></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.widgets.@NonNull QWebEngineScript other){
        return operator_equal_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineScript_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>runsOnSubFrames()const</code></p>
     */
    @QtUninvokable
    public final boolean runsOnSubFrames(){
        return runsOnSubFrames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean runsOnSubFrames_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>setInjectionPoint(QWebEngineScript::InjectionPoint)</code></p>
     */
    @QtUninvokable
    public final void setInjectionPoint(io.qt.webengine.widgets.QWebEngineScript.@NonNull InjectionPoint arg__1){
        setInjectionPoint_native_QWebEngineScript_InjectionPoint(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1.value());
    }
    
    @QtUninvokable
    private native void setInjectionPoint_native_QWebEngineScript_InjectionPoint(long __this__nativeId, int arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>setName(QString)</code></p>
     */
    @QtUninvokable
    public final void setName(java.lang.@NonNull String arg__1){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>setRunsOnSubFrames(bool)</code></p>
     */
    @QtUninvokable
    public final void setRunsOnSubFrames(boolean on){
        setRunsOnSubFrames_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), on);
    }
    
    @QtUninvokable
    private native void setRunsOnSubFrames_native_bool(long __this__nativeId, boolean on);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>setSourceCode(QString)</code></p>
     */
    @QtUninvokable
    public final void setSourceCode(java.lang.@NonNull String arg__1){
        setSourceCode_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void setSourceCode_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>setWorldId(quint32)</code></p>
     */
    @QtUninvokable
    public final void setWorldId(int arg__1){
        setWorldId_native_quint32(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void setWorldId_native_quint32(long __this__nativeId, int arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>sourceCode()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String sourceCode(){
        return sourceCode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String sourceCode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>swap(QWebEngineScript&amp;)</code></p>
     */
    @QtUninvokable
    public final void swap(io.qt.webengine.widgets.@StrictNonNull QWebEngineScript other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QWebEngineScript(long __this__nativeId, long other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr>worldId()const</code></p>
     */
    @QtUninvokable
    public final int worldId(){
        return worldId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int worldId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineScript(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>QWebEngineScript::<wbr>operator==(QWebEngineScript)const</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineScript) {
            return operator_equal((io.qt.webengine.widgets.QWebEngineScript) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineScript)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    /**
     * <p>See <code>operator&lt;&lt;(QDebug,<wbr>QWebEngineScript)</code></p>
     */
    @QtUninvokable
    @Override
    public @NonNull String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineScript clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineScript clone_native(long __this_nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.widgets.QWebEngineScript)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.widgets.@NonNull QWebEngineScript other) {
        assign(other);
    }
}

==> qtjambi-webenginewidgets-5.15.18-sources.jar: io/qt/webengine/widgets/QWebEngineScript.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Encapsulates a JavaScript program</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html">QWebEngineScript</a></code></p>
 */
public class QWebEngineScript extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::InjectionPoint</a></code></p>
     */
    public enum InjectionPoint implements QtEnumerator {
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::<wbr/>Deferred</a></code></p>
         */
        Deferred(0),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::<wbr/>DocumentReady</a></code></p>
         */
        DocumentReady(1),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#InjectionPoint-enum">QWebEngineScript::<wbr/>DocumentCreation</a></code></p>
         */
        DocumentCreation(2);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private InjectionPoint(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull InjectionPoint resolve(int value) {
            switch (value) {
            case 0: return Deferred;
            case 1: return DocumentReady;
            case 2: return DocumentCreation;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::ScriptWorldId</a></code></p>
     */
    public enum ScriptWorldId implements QtEnumerator {
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::<wbr/>MainWorld</a></code></p>
         */
        MainWorld(0),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::<wbr/>ApplicationWorld</a></code></p>
         */
        ApplicationWorld(1),
        /**
         * <p>Representing <code><a href="http://doc.qt.io/qt-5/qwebenginescript.html#ScriptWorldId-enum">QWebEngineScript::<wbr/>UserWorld</a></code></p>
         */
        UserWorld(2);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private ScriptWorldId(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull ScriptWorldId resolve(int value) {
            switch (value) {
            case 0: return MainWorld;
            case 1: return ApplicationWorld;
            case 2: return UserWorld;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>QWebEngineScript()</code></p>
     */
    public QWebEngineScript(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QWebEngineScript instance);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>QWebEngineScript(QWebEngineScript)</code></p>
     */
    public QWebEngineScript(io.qt.webengine.widgets.@NonNull QWebEngineScript other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineScript instance, io.qt.webengine.widgets.QWebEngineScript other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>injectionPoint()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineScript.@NonNull InjectionPoint injectionPoint(){
        return io.qt.webengine.widgets.QWebEngineScript.InjectionPoint.resolve(injectionPoint_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int injectionPoint_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>isNull()const</code></p>
     */
    @QtUninvokable
    public final boolean isNull(){
        return isNull_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isNull_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>name()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String name(){
        return name_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String name_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>operator=(QWebEngineScript)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineScript other){
        assign_native_cref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineScript(long __this__nativeId, long other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>operator==(QWebEngineScript)const</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.webengine.widgets.@NonNull QWebEngineScript other){
        return equals_native_cref_QWebEngineScript_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QWebEngineScript_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>runsOnSubFrames()const</code></p>
     */
    @QtUninvokable
    public final boolean runsOnSubFrames(){
        return runsOnSubFrames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean runsOnSubFrames_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>setInjectionPoint(QWebEngineScript::InjectionPoint)</code></p>
     */
    @QtUninvokable
    public final void setInjectionPoint(io.qt.webengine.widgets.QWebEngineScript.@NonNull InjectionPoint arg__1){
        setInjectionPoint_native_QWebEngineScript_InjectionPoint(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1.value());
    }
    
    @QtUninvokable
    private native void setInjectionPoint_native_QWebEngineScript_InjectionPoint(long __this__nativeId, int arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>setName(QString)</code></p>
     */
    @QtUninvokable
    public final void setName(java.lang.@NonNull String arg__1){
        setName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void setName_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>setRunsOnSubFrames(bool)</code></p>
     */
    @QtUninvokable
    public final void setRunsOnSubFrames(boolean on){
        setRunsOnSubFrames_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), on);
    }
    
    @QtUninvokable
    private native void setRunsOnSubFrames_native_bool(long __this__nativeId, boolean on);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>setSourceCode(QString)</code></p>
     */
    @QtUninvokable
    public final void setSourceCode(java.lang.@NonNull String arg__1){
        setSourceCode_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void setSourceCode_native_cref_QString(long __this__nativeId, java.lang.String arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>setWorldId(quint32)</code></p>
     */
    @QtUninvokable
    public final void setWorldId(int arg__1){
        setWorldId_native_quint32(QtJambi_LibraryUtilities.internal.nativeId(this), arg__1);
    }
    
    @QtUninvokable
    private native void setWorldId_native_quint32(long __this__nativeId, int arg__1);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>sourceCode()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String sourceCode(){
        return sourceCode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String sourceCode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>swap(QWebEngineScript&amp;)</code></p>
     */
    @QtUninvokable
    public final void swap(io.qt.webengine.widgets.@StrictNonNull QWebEngineScript other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineScript(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QWebEngineScript(long __this__nativeId, long other);
    
    /**
     * <p>See <code>QWebEngineScript::<wbr/>worldId()const</code></p>
     */
    @QtUninvokable
    public final int worldId(){
        return worldId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int worldId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineScript(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>QWebEngineScript::<wbr/>operator==(QWebEngineScript)const</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineScript) {
            return equals((io.qt.webengine.widgets.QWebEngineScript) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineScript)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    /**
     * <p>See <code>operator&lt;&lt;(QDebug,<wbr/>QWebEngineScript)</code></p>
     */
    @QtUninvokable
    @Override
    public @NonNull String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineScript clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineScript clone_native(long __this_nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.widgets.QWebEngineScript)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.widgets.@NonNull QWebEngineScript other) {
        assign(other);
    }
}
